@@ -54,19 +54,14 @@ class KMixerWidget : public QWidget
   public:
    explicit KMixerWidget( Mixer *mixer,
                           QWidget *parent, ViewBase::ViewFlags vflags, const QString  &guiprofId, KActionCollection* coll = nullptr );
-   ~KMixerWidget();
-
-   Mixer *mixer() { return _mixer; }
-   ViewBase* currentView();
-   GUIProfile* getGuiprof() { return GUIProfile::find(_guiprofId); }
+   virtual ~KMixerWidget();
 
+    Mixer *mixer() const			{ return (_mixer); }
+    GUIProfile *getGuiprof() const		{ return (GUIProfile::find(_guiprofId)); }
+    ViewBase *currentView() const;
    
-  Q_SIGNALS:
-   void toggleMenuBar();
-    
   public Q_SLOTS:
    void setIcons( bool on );
-   void toggleMenuBarSlot();
 
    void saveConfig( KConfig *config );
    void loadConfig( KConfig *config );
